RawPacket

Struct RawPacket 

pub struct RawPacket<'a> {
    pub tpacket3_hdr: Tpacket3Hdr,
    pub data: &'a [u8],
}
Contains a reference to an individual packet in a block, as well as details about that packet

Fields

tpacket3_hdr: Tpacket3Hdr

Contains packet details

data: &'a [u8]

Raw packet data including any encapsulations